        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 28 <br>2,7,8,9,11,13,14,15,16,18,19,22,26,27,30,32,34,35,36,38,40,41,42,43,44,47,48,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 23 <strong>control</strong><br>0,1,3,4,5,6,10,12,17,20,21,23,24,25,28,29,31,33,37,39,45,46,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 28 <br>2,7,8,9,11,13,14,15,16,18,19,22,26,27,30,32,34,35,36,38,40,41,42,43,44,47,48,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 23 <strong>control</strong><br>0,1,3,4,5,6,10,12,17,20,21,23,24,25,28,29,31,33,37,39,45,46,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 28 <br>2,7,8,9,11,13,14,15,16,18,19,22,26,27,30,32,34,35,36,38,40,41,42,43,44,47,48,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 23 <strong>control</strong><br>0,1,3,4,5,6,10,12,17,20,21,23,24,25,28,29,31,33,37,39,45,46,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 28 <br>2,7,8,9,11,13,14,15,16,18,19,22,26,27,30,32,34,35,36,38,40,41,42,43,44,47,48,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 23 <strong>control</strong><br>0,1,3,4,5,6,10,12,17,20,21,23,24,25,28,29,31,33,37,39,45,46,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 28 <br>2,7,8,9,11,13,14,15,16,18,19,22,26,27,30,32,34,35,36,38,40,41,42,43,44,47,48,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260518 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 23 <strong>control</strong><br>0,1,3,4,5,6,10,12,17,20,21,23,24,25,28,29,31,33,37,39,45,46,50';}
}
